==> ejc-procurement-api-3.0.0-20251215.092516-126-sources.jar: com/ejianc/business/procurement/perform/vo/ReviewAnnounceConfirmVO.java <==
package com.ejianc.business.procurement.perform.vo;

import com.ejianc.business.procurement.utils.ITreeNodeB;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;


/**
 * 采购前公示结果评审-审查清单
 * 
 * @author generator
 * 
 */
public class ReviewAnnounceConfirmVO extends BaseVO implements ITreeNodeB {
    private static final long serialVersionUID = 1L;
    
    private Long pid; // 主表主键
    private Integer sequence; // 排序
    private String name; // 审查内容及标准
    private String code; // 编码
    private Long parentId; // 父ID
    private List<ITreeNodeB> children;
    private String tid;
    private String tpid;
    private List<ReviewAnnounceSupplierVO> supplierList = new ArrayList<>();

    public List<ReviewAnnounceSupplierVO> getSupplierList() {
        return supplierList;
    }

    public void setSupplierList(List<ReviewAnnounceSupplierVO> supplierList) {
        this.supplierList = supplierList;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    @Override
    public Long getNodeID() {
        return getId();
    }

    @Override
    public Long getParentID() {
        return parentId;
    }

    public List<ITreeNodeB> getChildren() {
        if (children == null) {
            children = new ArrayList<>();
        }
        return children;

    }
}

==> ejc-procurement-api-3.0.0-20251216.072949-134-sources.jar: com/ejianc/business/procurement/perform/vo/ReviewAnnounceConfirmVO.java <==
package com.ejianc.business.procurement.perform.vo;

import com.ejianc.business.procurement.utils.ITreeNodeB;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;


/**
 * 采购前公示结果评审-审查清单
 * 
 * @author generator
 * 
 */
public class ReviewAnnounceConfirmVO extends BaseVO implements ITreeNodeB {
    private static final long serialVersionUID = 1L;
    
    private Long pid; // 主表主键
    private Integer sequence; // 排序
    private String name; // 审查内容及标准
    private String code; // 编码
    private Long parentId; // 父ID
    private List<ITreeNodeB> children;
    private String tid;
    private String tpid;
    /**
     * 序号
     */
    private String detailIndex;
    private List<ReviewAnnounceSupplierVO> supplierList = new ArrayList<>();

    public String getDetailIndex() {
        return detailIndex;
    }

    public void setDetailIndex(String detailIndex) {
        this.detailIndex = detailIndex;
    }

    public List<ReviewAnnounceSupplierVO> getSupplierList() {
        return supplierList;
    }

    public void setSupplierList(List<ReviewAnnounceSupplierVO> supplierList) {
        this.supplierList = supplierList;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    @Override
    public Long getNodeID() {
        return getId();
    }

    @Override
    public Long getParentID() {
        return parentId;
    }

    public List<ITreeNodeB> getChildren() {
        if (children == null) {
            children = new ArrayList<>();
        }
        return children;

    }
}
